/*
 * interrupt.h
 *
 * Copyright 2008, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */

#ifndef module_interrupt_h
#define module_interrupt_h

#include <sys/Thread.h>

#ifndef ASM_FILE

extern ThreadObj *IntrDscGetTask(const int);
extern void *IntrDscGetArg(const int);
extern void *IntrDscGetReturnMethod(const int);
extern void *IntrDscGetStackPoint(const int);
extern int sysIntrEstablish();
extern int sysIntrDisestablish();

#endif // ASM_FILE

#endif // module_interrupt_h
